@@ -54,6 +54,8 @@
   (-> "Whitespace" (link space-menu))
   (-> "Indentation" (link indentation-menu))
   (-> "Break" (link break-menu))
+  (when (and (selection-active-small?) (tm-atomic? (selection-tree)))
+    ("Hyphenate as" (interactive hyphenate-selection-as)))
   ---
   (-> "Color"
       (if (== (get-preference "experimental alpha") "on")
@@ -193,6 +195,8 @@
       ("C++" (make 'cpp))
       ("Mathemagix" (make 'mmx))
       ("Python" (make 'python))
+      ("R" (make 'r))
+      ("Scala" (make 'scala))
       ("Scheme" (make 'scm))
       ("Shell" (make 'shell))
       ("Scilab" (make 'scilab))
@@ -201,6 +205,8 @@
       ("C++" (make 'cpp-code))
       ("Mathemagix" (make 'mmx-code))
       ("Python" (make 'python-code))
+      ("R" (make 'r-code))
+      ("Scala" (make 'scala-code))
       ("Scheme" (make 'scm-code))
       ("Shell" (make 'shell-code))
       ("Scilab" (make 'scilab-code))
@@ -217,6 +223,7 @@
     ;;("Balloon" (make-balloon))
     ---
     ("Floating object" (make-insertion "float"))
+    ("Floating phantom" (insert '(phantom-float "float" "hf")))
     ("Floating figure" (begin (make-insertion "float") (make 'big-figure)))
     ("Floating table" (begin (make-insertion "float")
                              (insert-go-to '(big-table "" "") '(0 0))
@@ -249,22 +256,36 @@
   ("Top" (toggle-insertion-positioning "t"))
   ("Here" (toggle-insertion-positioning "h"))
   ("Bottom" (toggle-insertion-positioning "b"))
-  ("Other pages" (toggle-insertion-positioning-not "f")))
+  ("Other pages" (toggle-insertion-positioning-not "f"))
+  (if (tree-innermost float-context? #t)
+      ---
+      ("Make non floating"
+       (turn-non-floating (tree-innermost float-context? #t)))))
 
 (tm-menu (focus-float-menu t)
-  (:require (float-context? t))
+  (:require (rich-float-context? t))
+  (if (in-multicol-style?)
+      ("Wide float" (float-toggle-wide (focus-tree))))
   (-> "Allowed positions" (link float-menu))
   (if (cursor-at-anchor?)
       ("Go to float" (go-to-float)))
   (if (not (cursor-at-anchor?))
       ("Go to anchor" (go-to-anchor))))
 
+(tm-menu (focus-float-menu t)
+  (:require (phantom-float-context? t))
+  (-> "Allowed positions" (link float-menu)))
+
 (tm-menu (focus-float-menu t)
   (:require (floatable-context? t))
-  ("Make floating" (turn-floating t)))
+  (if (in-multicol-style?)
+      ("Span over all columns" (floatable-toggle-wide t)))
+  ("Make floating" (turn-floating (tree-innermost floatable-context?))))
 
 (tm-menu (focus-float-menu t)
   (:require (tree-is? t 'footnote))
+  (if (in-multicol-style?)
+      ("Wide footnote" (float-toggle-wide (focus-tree))))
   (if (cursor-at-anchor?)
       ("Go to footnote" (go-to-float)))
   (if (not (cursor-at-anchor?))
@@ -416,7 +437,10 @@
   (assuming (get-boolean-preference "gui:new bibliography dialogue")
     ("Bibliography" (interactive open-bibliography-inserter)))
   (assuming (not (get-boolean-preference "gui:new bibliography dialogue"))
-    ("Bibliography" (interactive make-bib)))
+    (if (with-database-tool?)
+        ("Bibliography" (make-database-bib)))
+    (if (not (with-database-tool?))
+        ("Bibliography" (choose-file make-bib "Bibliography file" "BibTeX"))))
   ("Index" (make-aux "the-index" "index-prefix" "idx"))
   ("Glossary" (make-aux "the-glossary" "glossary-prefix" "gly"))
   ;;("List of figures" (make-aux* "the-glossary*" "figure-list-prefix" "figure" "List of figures"))
@@ -431,7 +455,8 @@
 (menu-bind text-block-menu
   (if (and (style-has? "header-title-dtd")
            (not (style-has? "header-letter-dtd"))
-           (not (style-has? "header-exam-dtd")))
+           (not (style-has? "header-exam-dtd"))
+           (not (in-poster?)))
       (-> "Title" (link title-menu)))
   (if (style-has? "header-letter-dtd")
       (-> "Header" (link letter-header-menu)))
@@ -498,16 +523,24 @@
       (=> (balloon (icon "tm_chapter.xpm") "Start a new chapter")
           (link chapter-menu)))
   (if (and (style-has? "section-base-dtd")
-           (not (style-has? "header-exam-dtd")))
+           (not (style-has? "header-exam-dtd"))
+           (not (in-poster?)))
       (=> (balloon (icon "tm_section.xpm") "Start a new section")
           (link section-menu)))
+  (if (in-poster?)
+      (=> (balloon (icon "tm_block.xpm") "Insert a section block")
+          (link poster-block-menu)))
   (if (or (style-has? "env-theorem-dtd")
           (style-has? "header-exam-dtd"))
       (=> (balloon (icon "tm_theorem.xpm") "Insert an enunciation")
           (link enunciation-menu)))
-  (if (style-has? "std-markup-dtd")
+  (if (and (style-has? "std-markup-dtd") (not (in-poster?)))
       (=> (balloon (icon "tm_prominent.xpm") "Insert a prominent piece of text")
           (link prominent-menu)))
+  (if (and (style-has? "std-markup-dtd") (in-poster?))
+      (=> (balloon (icon "tm_var_prominent.xpm")
+                   "Insert a prominent piece of text")
+          (link prominent-menu)))
   (if (style-has? "std-markup-dtd")
       (=> (balloon (icon "tm_program.xpm") "Insert a computer program")
           (link code-menu)))
@@ -590,7 +623,10 @@
       /)
   (link text-inline-icons)
   (if (in-manual?) (link tmdoc-icons))
-  (link texmacs-insert-icons))
+  (link texmacs-insert-icons)
+  (if (and (in-presentation?) (not (visible-icon-bar? 0)))
+    /
+    (link dynamic-icons)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menus for entering title information
@@ -797,13 +833,17 @@
     (=> (eval (tm/section-get-title-string t))
         (link focus-section-menu))))
 
+(tm-define (child-proposals t i)
+  (:require (and (tree-in? t '(bibliography bibliography*)) (== i 1)))
+  (bib-standard-styles))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menu for lists
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (standard-options l)
   (:require (in? l (list-tag-list)))
-  (list "compact-list"))
+  (list "compact-list" "triangle-list"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Focus menu for theorems and proofs
@@ -877,7 +917,11 @@
       (link position-marginal-note-menu)))
 
 (tm-menu (focus-float-icons t)
-  (:require (float-context? t))
+  (:require (rich-float-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make float wide") "v"
+              (float-wide? (focus-tree)))
+       (float-toggle-wide (focus-tree))))
   (=> (balloon (icon "tm_position_float.xpm")
                "Allowed positions of floating object")
       (link float-menu))
@@ -886,13 +930,27 @@
    (cursor-toggle-anchor)))
 
 (tm-menu (focus-float-icons t)
-  (:require (floatable-context? t))
-  ((balloon (icon "tm_position_float.xpm")
-            "Let the environment float")
-   (turn-floating t)))
+  (:require (phantom-float-context? t))
+  (=> (balloon (icon "tm_position_float.xpm")
+               "Allowed positions of floating object")
+      (link float-menu)))
 
 (tm-menu (focus-float-icons t)
-  (:require (tree-is? t 'footnote))
+  (:require (floatable-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make wide") "v"
+              (floatable-wide? (focus-tree)))
+       (floatable-toggle-wide (focus-tree))))
+  ((balloon (icon "tm_position_float.xpm")
+            "Let the environment float")
+   (turn-floating (tree-innermost floatable-context?))))
+
+(tm-menu (focus-float-icons t)
+  (:require (footnote-context? t))
+  (if (in-multicol-style?)
+      ((check (balloon (icon "tm_wide_float.xpm") "Make footnote wide") "v"
+              (float-wide? (focus-tree)))
+       (float-toggle-wide (focus-tree))))
   ((balloon (icon "tm_anchor.xpm")
             "Go to anchor or footnote")
    (cursor-toggle-anchor)))
